@@ -16,38 +16,42 @@
 #' @export
 
 
-NNS.mode <- function(x, discrete = FALSE, multi = TRUE){
+NNS.mode <- function (x, discrete = FALSE, multi = TRUE)
+{
   x <- as.numeric(x)
   l <- length(x)
-  if(l <= 3) return(median(x))
-  if(length(unique(x))==1) return(x[1])
+  if (l <= 3)
+    return(median(x))
+  if (length(unique(x)) == 1)
+    return(x[1])
   x_s <- x[order(x)]
-  range <- abs(x_s[l]-x_s[1])
-  if(range==0) return(x[1])
-  
+  range <- abs(x_s[l] - x_s[1])
+  if (range == 0)
+    return(x[1])
   z <- NNS_bin(x_s, range/128, origin = x_s[1], missinglast = FALSE)
   lz <- length(z$counts)
-  max_z <- z$counts==max(z$counts)
+  max_z <- z$counts == max(z$counts)
   z_names <- seq(x_s[1], x_s[l], z$width)
-  
-  if(sum(max_z)>1){
+  if (sum(max_z) > 1) {
     z_ind <- 1:lz
-    if(multi) return(z_names[max_z])
-  } else {
-    z_c <- which.max(z$counts)
-    z_ind <- max(1, (z_c - 1)):min(lz,(z_c + 1))
+    if (multi)
+      return(z_names[max_z])
   }
-  
-  final <- sum(z_names[z_ind] * z$counts[z_ind] )/sum(z$counts[z_ind])
-  
-  if(discrete){
-    final <- ifelse(final%%1 < .5, floor(final), ceiling(final))
+  else {
+    z_c <- which.max(z$counts)
+    z_ind <- max(1, (z_c - 1)):min(lz, (z_c + 1))
+  }
+  final <- sum(z_names[z_ind] * z$counts[z_ind])/sum(z$counts[z_ind])
+  if (discrete) {
+    final <- ifelse(final%%1 < 0.5, floor(final), ceiling(final))
     return(final)
-  } else {
-    if(multi){ 
-      return(final) 
-    } else {
-        return(mean(final))
+  }
+  else {
+    if (multi) {
+      return(final)
+    }
+    else {
+      return(mean(final))
     }
   }
 }
@@ -70,39 +74,56 @@ NNS.mode <- function(x, discrete = FALSE, multi = TRUE){
 #' }
 #' @export
 
-NNS.gravity <- function(x, discrete = FALSE){
+NNS.gravity <- function (x, discrete = FALSE)
+{
   l <- length(x)
-  if(l <= 3) return(median(x))
-  if(length(unique(x))==1) return(x[1])
+  if (l <= 3) return(median(x))
+  if (length(unique(x)) == 1) return(x[1])
+
   x_s <- x[order(x)]
-  range <- abs(x_s[l]-x_s[1])
-  
-  if(range == 0) return(x[1])
-  
-  q1 <- sum(x_s[floor(l*.25)]+((l*.25)%%1 * (x_s[ceiling(l*.25)] - x_s[floor(l*.25)])))
-  q2 <- (x_s[floor(l*.5)]+x_s[ceiling(l*.5)])/2
-  q3 <- sum(x_s[floor(l*.75)]+((l*.75)%%1 * (x_s[ceiling(l*.75)] - x_s[floor(l*.75)])))
-  
+  range <- abs(x_s[l] - x_s[1])
+
+  if (range == 0)  return(x[1])
+
+  l_25 = l*.25
+  l_50 = l*.5
+  l_75 = l*.75
+
+  if(l%%2==0){
+    q1 <- x_s[l_25]
+    q2 <- x_s[l_50]
+    q3 <- x_s[l_75]
+  } else {
+    f_l_25 = floor(l_25)
+    f_l_75 = floor(l_75)
+
+    q1 <- sum(x_s[f_l_25]+(l_25%%1 * (x_s[ceiling(l_25)] - x_s[f_l_25])))
+    q2 <- (x_s[floor(l_50)]+x_s[ceiling(l_50)])/2
+    q3 <- sum(x_s[f_l_75]+((l_75)%%1 * (x_s[ceiling(l_75)] - x_s[f_l_75])))
+  }
+
   z <- NNS_bin(x_s, range/128, origin = x_s[1], missinglast = FALSE)
   lz <- length(z$counts)
-  max_z <- z$counts==max(z$counts)
-  
-  if(sum(max_z)>1){
+  max_z <- z$counts == max(z$counts)
+  if (sum(max_z) > 1) {
     z_ind <- 1:lz
-  } else {
-    z_c <- which.max(z$counts)
-    z_ind <- max(1, (z_c - 1)):min(lz,(z_c + 1))
   }
-  
+  else {
+    z_c <- which.max(z$counts)
+    z_ind <- max(1, (z_c - 1)):min(lz, (z_c + 1))
+  }
   z_names <- seq(x_s[1], x_s[l], z$width)
-  
-  m <- sum(z_names[z_ind] * z$counts[z_ind] )/sum(z$counts[z_ind])
+  m <- sum(z_names[z_ind] * z$counts[z_ind])/sum(z$counts[z_ind])
   mu <- sum(x)/l
-  
   res <- (q2 + m + mu + mean(c(q1, q2, q3)))/4
-  if(is.na(res)) final <- q2 else final <- res
-  if(discrete) return(ifelse(final%%1 < .5, floor(final), ceiling(final))) else return(final)
-} 
+  if (is.na(res))
+    final <- q2
+  else final <- res
+  if (discrete)
+    return(ifelse(final%%1 < 0.5, floor(final), ceiling(final)))
+  else return(final)
+}
+
 
 
 #' NNS rescale
@@ -127,4 +148,6 @@ NNS.rescale <- function (x, a, b) {
   x <- as.numeric(x)
   output <- a + (b - a) * (x - min(x))/(max(x) - min(x))
   return(output)
-}
\ No newline at end of file
+}
+
+
